3.37.2 (2022-06-03)
===================
👷 Bug fixes
-----------

- pyramid: adapt TestApp.put_json method to CSRF

3.37.1 (2022-06-01)
===================
🎉 New features
--------------

- pkg: upgrade version of waitress to 2.1.1 or more, for security reason. (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/543)

👷 Bug fixes
-----------

- base64.decodestring is deprecated and has been removed
- pyramid tests: adapt TestApp.post_json method to CSRF
- pyramid tests: try to get "/login" if "/" is forbidden

3.37.0 (2022-03-31)
===================
Breaking changes
----------------

- cubicweb.web.BaseWebConfiguration and cubicweb.web.WebConfigurationBase
  have been merged into cubicweb.web.WebConfiguration
- cubicweb.web.CubicWebPyramidConfiguration had been removed
- you can nomore use -c option when creating a CW instance, since
  there is now only one kind of configuration: all-in-one.conf

🎉 New features
--------------

- add attributes constraints in exported schema
- depends on yams 0.48
- doc: mostly add links of issues

👷 Bug fixes
-----------

- unittest_devctl: give all debugging informations

🤖 Continuous integration
------------------------

- use templates

🤷 Various changes
-----------------

- refactor!: merge BaseWebConfiguration into WebConfiguration
- refactor!: remove -c option to 'cubicweb-ctl create' to only use all-in-one
- refactor!: remove unused CubicWebPyramidConfiguration
